@@ -12,13 +12,14 @@ package org.gnu.gnome;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.DruidPageChangeEvent;
 import org.gnu.gnome.event.DruidPageChangeListener;
 import org.gnu.gnome.event.DruidPageSetupEvent;
 import org.gnu.gnome.event.DruidPageSetupListener;
 import org.gnu.gtk.Bin;
-import org.gnu.gtk.event.GtkEventType;
 /**
  * This widget is a virtual widget to define the interface to a druid
  * page.
@@ -35,18 +36,36 @@ public class DruidPage extends Bin {
 	 */
 	public DruidPage() {
 		super(gnome_druid_page_new());
-		initializeEventHandlers();
 	}
 
 	/**
 	 * Constructs a new DruidPage object form a native resource.
 	 * @param handle The handle to the native resource.
 	 */
-	public DruidPage(int handle) {
+	public DruidPage(Handle handle) {
 		super(handle);
-		initializeEventHandlers();
 	}
 
+    public boolean pageNext() {
+        return gnome_druid_page_next(getHandle());
+    }
+    
+    public void pagePrepare() {
+        gnome_druid_page_prepare(getHandle());
+    }
+    
+    public boolean pageBack() {
+        return gnome_druid_page_back(getHandle());
+    }
+    
+    public boolean pageCancel() {
+        return gnome_druid_page_cancel(getHandle());
+    }
+    
+    public void pageFinish() {
+        gnome_druid_page_finish(getHandle());
+    }
+
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
@@ -66,14 +85,18 @@ public class DruidPage extends Bin {
 		int i = findListener(druidPageChangeListeners, listener);
 		if (i == -1) {
 			if (null == druidPageChangeListeners) {
+				evtMap.initialize(this, DruidPageChangeEvent.Type.BACK);
+				evtMap.initialize(this, DruidPageChangeEvent.Type.CANCEL);
+				evtMap.initialize(this, DruidPageChangeEvent.Type.NEXT);
 				druidPageChangeListeners = new Vector();
 			}
 			druidPageChangeListeners.addElement(listener);
 		}
 	}
+
 	/**
 	 * Removes a listener
-	 * @see #addListener(DruidPageChangeListeners)
+	 * @see #addListener(DruidPageChangeListener)
 	 */
 	public void removeListener(DruidPageChangeListener listener) {
 		int i = findListener(druidPageChangeListeners, listener);
@@ -81,9 +104,13 @@ public class DruidPage extends Bin {
 			druidPageChangeListeners.remove(i);
 		}
 		if (0 == druidPageChangeListeners.size()) {
+			evtMap.uninitialize(this, DruidPageChangeEvent.Type.BACK);
+			evtMap.uninitialize(this, DruidPageChangeEvent.Type.CANCEL);
+			evtMap.uninitialize(this, DruidPageChangeEvent.Type.NEXT);
 			druidPageChangeListeners = null;
 		}
 	}
+
 	protected boolean fireDruidPageChangeEvent(DruidPageChangeEvent event) {
 		if (null == druidPageChangeListeners) {
 			return false;
@@ -98,6 +125,7 @@ public class DruidPage extends Bin {
 		}
 		return false;
 	}
+
 	/**
 	 * Register an object to handle DruidPageSetup events.
 	 * @see org.gnu.gnome.event.DruidPageSetupListener
@@ -107,6 +135,8 @@ public class DruidPage extends Bin {
 		int i = findListener(druidPageSetupListeners, listener);
 		if (i == -1) {
 			if (null == druidPageSetupListeners) {
+				evtMap.initialize(this, DruidPageSetupEvent.Type.FINISH);
+				evtMap.initialize(this, DruidPageSetupEvent.Type.PREPARE);
 				druidPageSetupListeners = new Vector();
 			}
 			druidPageSetupListeners.addElement(listener);
@@ -114,7 +144,7 @@ public class DruidPage extends Bin {
 	}
 	/**
 	 * Removes a listener
-	 * @see #addListener(DruidPageSetupListeners)
+	 * @see #addListener(DruidPageSetupListener)
 	 */
 	public void removeListener(DruidPageSetupListener listener) {
 		int i = findListener(druidPageSetupListeners, listener);
@@ -122,6 +152,8 @@ public class DruidPage extends Bin {
 			druidPageSetupListeners.remove(i);
 		}
 		if (0 == druidPageSetupListeners.size()) {
+			evtMap.uninitialize(this, DruidPageSetupEvent.Type.FINISH);
+			evtMap.uninitialize(this, DruidPageSetupEvent.Type.PREPARE);
 			druidPageSetupListeners = null;
 		}
 	}
@@ -138,42 +170,34 @@ public class DruidPage extends Bin {
 		}
 	}
 
-	private boolean handleNext(int widget) {
+	private boolean handleNext(Handle widget) {
 		return fireDruidPageChangeEvent(new DruidPageChangeEvent(this, DruidPageChangeEvent.Type.NEXT));
 	}
 
-	private boolean handleBack(int widget) {
+	private boolean handleBack(Handle widget) {
 		return fireDruidPageChangeEvent(new DruidPageChangeEvent(this, DruidPageChangeEvent.Type.BACK));
 	}
 
-	private void handleFinish(int widget) {
+	private void handleFinish(Handle widget) {
 		fireDruidPageSetupEvent(new DruidPageSetupEvent(this, DruidPageSetupEvent.Type.FINISH));
 	}
 
-	private boolean handleCancel(int widget) {
+	private boolean handleCancel(Handle widget) {
 		return fireDruidPageChangeEvent(new DruidPageChangeEvent(this, DruidPageChangeEvent.Type.CANCEL));
 	}
 
-	private void handlePrepare(int widget) {
+	private void handlePrepare(Handle widget) {
 		fireDruidPageSetupEvent(new DruidPageSetupEvent(this, DruidPageSetupEvent.Type.PREPARE));
 	}
 
-	protected void initializeEventHandlers() {
-		if (!eventsInitialized) {
-			super.initializeEventHandlers();
-			evtMap.initialize(this);
-			eventsInitialized = true;
-		}
-	}
-
 	public Class getEventListenerClass(String signal) {
 		Class cls = evtMap.getEventListenerClass(signal);
 		if (cls == null) cls = super.getEventListenerClass(signal);
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
@@ -191,17 +215,13 @@ public class DruidPage extends Bin {
 		anEvtMap.addEvent("prepare", "handlePrepare", DruidPageSetupEvent.Type.PREPARE, DruidPageSetupListener.class);
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_druid_page_get_type();
-	native static final protected int gnome_druid_page_new();
-	native static final protected boolean gnome_druid_page_next(int page);
-	native static final protected void gnome_druid_page_prepare(int page);
-	native static final protected boolean gnome_druid_page_back(int page);
-	native static final protected boolean gnome_druid_page_cancel(int page);
-	native static final protected void gnome_druid_page_finish(int page);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_druid_page_new();
+	native static final protected boolean gnome_druid_page_next(Handle page);
+	native static final protected void gnome_druid_page_prepare(Handle page);
+	native static final protected boolean gnome_druid_page_back(Handle page);
+	native static final protected boolean gnome_druid_page_cancel(Handle page);
+	native static final protected void gnome_druid_page_finish(Handle page);
+
 }
