@@ -8,9 +8,9 @@
  */
 
 package org.gnu.gnome;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 /**
- *
  */
 public class PixmapEntry extends FileEntry {
 	/**
@@ -23,7 +23,7 @@ public class PixmapEntry extends FileEntry {
 	/**
 	 * Construct a new PixmapEntry from a handle to a native resource.
 	 */
-	public PixmapEntry(int handle) {
+	public PixmapEntry(Handle handle) {
 	    super(handle);
 	}
 	
@@ -62,18 +62,14 @@ public class PixmapEntry extends FileEntry {
 		return new Type(gnome_pixmap_entry_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_pixmap_entry_get_type();
-	native static final protected int gnome_pixmap_entry_new(String historyId, String browseDialogTitle, boolean doPreview);
-	native static final protected void gnome_pixmap_entry_set_pixmap_subdir(int pentry, String subdir);
-	native static final protected int gnome_pixmap_entry_scrolled_window(int pentry);
-	native static final protected int gnome_pixmap_entry_preview_widget(int pentry);
-	native static final protected void gnome_pixmap_entry_set_preview(int pentry, boolean doPreview);
-	native static final protected void gnome_pixmap_entry_set_preview_size(int pentry, int width, int height);
-	native static final protected String gnome_pixmap_entry_get_filename(int pentry);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_pixmap_entry_new(String historyId, String browseDialogTitle, boolean doPreview);
+	native static final protected void gnome_pixmap_entry_set_pixmap_subdir(Handle pentry, String subdir);
+	native static final protected Handle gnome_pixmap_entry_scrolled_window(Handle pentry);
+	native static final protected Handle gnome_pixmap_entry_preview_widget(Handle pentry);
+	native static final protected void gnome_pixmap_entry_set_preview(Handle pentry, boolean doPreview);
+	native static final protected void gnome_pixmap_entry_set_preview_size(Handle pentry, int width, int height);
+	native static final protected String gnome_pixmap_entry_get_filename(Handle pentry);
+
 }
